package sun.java2d.cmm.lcms;

import java.util.Arrays;
import java.util.HashMap;
import sun.java2d.cmm.Profile;

final class LCMSProfile extends Profile
{
    private final LCMSProfile.TagCache tagCache;
    private final Object disposerReferent;
    
    LCMSProfile(long ptr, Object disposerReferent) {
        super(ptr);
        this.disposerReferent = disposerReferent;
        this.tagCache = new LCMSProfile.TagCache(this);
    }
    
    final long getLcmsPtr() {
        return this.getNativePtr();
    }
    
    LCMSProfile.TagData getTag(int n) {
        return this.tagCache.getTag(n);
    }
    
    void clearTagCache() {
        this.tagCache.clear();
    }
    
    static long access$000(LCMSProfile lcmsProfile) {
        return lcmsProfile.getNativePtr();
    }
    
    static class TagCache
    {
        final LCMSProfile profile;
        private HashMap<Integer, LCMSProfile.TagData> tags;
        
        TagCache(LCMSProfile profile) {
            this.profile = profile;
            this.tags = new HashMap();
        }
        
        LCMSProfile.TagData getTag(int n) {
            LCMSProfile.TagData value = (LCMSProfile.TagData)this.tags.get(Integer.valueOf(n));
            if (value == null) {
                byte[] tagNative = LCMS.getTagNative(LCMSProfile.access$000(this.profile), n);
                if (tagNative != null) {
                    value = new LCMSProfile.TagData(n, tagNative);
                    this.tags.put(Integer.valueOf(n), value);
                }
            }
            return value;
        }
        
        void clear() {
            this.tags.clear();
        }
    }
    
    static class TagData
    {
        private int signature;
        private byte[] data;
        
        TagData(int signature, byte[] data) {
            this.signature = signature;
            this.data = data;
        }
        
        int getSize() {
            return this.data.length;
        }
        
        byte[] getData() {
            return Arrays.copyOf(this.data, this.data.length);
        }
        
        void copyDataTo(byte[] array) {
            System.arraycopy(this.data, 0, array, 0, this.data.length);
        }
        
        int getSignature() {
            return this.signature;
        }
    }
}
